@@ -37,6 +37,8 @@
  *
  */
 
+ParseData gParse;
+
 int Fits_MainCommand( ClientData clientData,
 		      Tcl_Interp *interp,
 		      int argc,
@@ -956,6 +958,8 @@ static int fitsEvaluateExpr( char *expr )
 {
    int lexpr;
    Tcl_Interp *interp = vexprInfo.interp;
+   yyscan_t yylex_scanner; /* Used internally by FLEX lexer */
+   int status = 0;
 
    /*************************************/
    /*  Initialize the Parser structure  */
@@ -993,15 +997,20 @@ static int fitsEvaluateExpr( char *expr )
    /*  Parse the expression, building the Nodes and determining  */
    /*  which columns are needed and what data type is returned   */
 
+
+
    vexprInfo.nrows = 0;
-   ffrestart(NULL);
-   if( ffparse() ) {
+   fits_parser_yylex_init_extra(&gParse, &yylex_scanner);
+   fits_parser_yyrestart(NULL, yylex_scanner);
+   status = fits_parser_yyparse(yylex_scanner, &gParse);
+   fits_parser_yylex_destroy(yylex_scanner);
+   free  ( gParse.expr );
+
+   if ( status ) {
       dumpFitsErrStack( interp, PARSE_SYNTAX_ERR );
-      free  ( gParse.expr );
       fitsExprCleanup();
       return TCL_ERROR;
    }
-   free( gParse.expr );
 
    if( gParse.status ) {
       dumpFitsErrStack( interp, gParse.status );
@@ -1020,7 +1029,7 @@ static int fitsEvaluateExpr( char *expr )
    gParse.firstDataRow = 1;
    gParse.nDataRows    = gParse.totalRows  = vexprInfo.nrows;
 
-   Evaluate_Parser( 1L, vexprInfo.nrows );
+   Evaluate_Parser( &gParse, 1L, vexprInfo.nrows );
 
    if( gParse.status ) {
       dumpFitsErrStack( interp, gParse.status );
@@ -1033,7 +1042,7 @@ static int fitsEvaluateExpr( char *expr )
 
 static int fitsGetData( char *dataName, void *itslval )
 {
-   FFSTYPE *thelval = (FFSTYPE*)itslval;
+   YYSTYPE *thelval = (YYSTYPE*)itslval;
    Tcl_Interp *interp;
    Tcl_Obj **argv;
    int argc, nrows, datatype, naxis, i, nCol, type;
