@@ -1,5 +1,4 @@
-
-#include <tcl.h>
+#include <fitsTcl.h>
 
 #ifdef macintosh
 #pragma export on
